==> kubernetes-1.31.9.tar.xz: kubernetes-1.31.9/pkg/scheduler/framework/plugins/names/names.go <==
/*
Copyright 2021 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package names

const (
	PrioritySort                    = "PrioritySort"
	DefaultBinder                   = "DefaultBinder"
	DefaultPreemption               = "DefaultPreemption"
	DynamicResources                = "DynamicResources"
	ImageLocality                   = "ImageLocality"
	InterPodAffinity                = "InterPodAffinity"
	NodeAffinity                    = "NodeAffinity"
	NodeName                        = "NodeName"
	NodePorts                       = "NodePorts"
	NodeResourcesBalancedAllocation = "NodeResourcesBalancedAllocation"
	NodeResourcesFit                = "NodeResourcesFit"
	NodeUnschedulable               = "NodeUnschedulable"
	NodeVolumeLimits                = "NodeVolumeLimits"
	AzureDiskLimits                 = "AzureDiskLimits"
	CinderLimits                    = "CinderLimits"
	EBSLimits                       = "EBSLimits"
	GCEPDLimits                     = "GCEPDLimits"
	PodTopologySpread               = "PodTopologySpread"
	SchedulingGates                 = "SchedulingGates"
	TaintToleration                 = "TaintToleration"
	VolumeBinding                   = "VolumeBinding"
	VolumeRestrictions              = "VolumeRestrictions"
	VolumeZone                      = "VolumeZone"
)

==> kubernetes-1.35.0.tar.xz: kubernetes-1.35.0/pkg/scheduler/framework/plugins/names/names.go <==
/*
Copyright 2021 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package names

const (
	PrioritySort                    = "PrioritySort"
	DefaultBinder                   = "DefaultBinder"
	DefaultPreemption               = "DefaultPreemption"
	DynamicResources                = "DynamicResources"
	GangScheduling                  = "GangScheduling"
	ImageLocality                   = "ImageLocality"
	InterPodAffinity                = "InterPodAffinity"
	NodeAffinity                    = "NodeAffinity"
	NodeDeclaredFeatures            = "NodeDeclaredFeatures"
	NodeName                        = "NodeName"
	NodePorts                       = "NodePorts"
	NodeResourcesBalancedAllocation = "NodeResourcesBalancedAllocation"
	NodeResourcesFit                = "NodeResourcesFit"
	NodeUnschedulable               = "NodeUnschedulable"
	NodeVolumeLimits                = "NodeVolumeLimits"
	PodTopologySpread               = "PodTopologySpread"
	SchedulingGates                 = "SchedulingGates"
	TaintToleration                 = "TaintToleration"
	VolumeBinding                   = "VolumeBinding"
	VolumeRestrictions              = "VolumeRestrictions"
	VolumeZone                      = "VolumeZone"
)
